@@ -3,24 +3,25 @@ package Convert::Pheno;
 use strict;
 use warnings;
 use autodie;
-use feature qw(say);
+use feature               qw(say);
 use File::Spec::Functions qw(catdir catfile);
 use Data::Dumper;
 use Path::Tiny;
 use File::Basename;
 use File::ShareDir::ProjectDistDir;
 use List::Util qw(any uniq);
-use Carp qw(confess);
+use Carp       qw(confess);
 use XML::Fast;
 use Moo;
-use Types::Standard qw(Str Int Num Enum ArrayRef Undef);
+use Types::Standard                qw(Str Int Num Enum ArrayRef Undef);
 use File::ShareDir::ProjectDistDir qw(dist_dir);
 
 #use Devel::Size     qw(size total_size);
-use Convert::Pheno::CSV;
-use Convert::Pheno::IO;
+use Convert::Pheno::IO::CSVHandler;
+use Convert::Pheno::IO::FileIO;
 use Convert::Pheno::SQLite;
 use Convert::Pheno::Mapping;
+use Convert::Pheno::CSV qw(do_bff2csv do_pxf2csv);
 use Convert::Pheno::OMOP;
 use Convert::Pheno::PXF;
 use Convert::Pheno::BFF;
@@ -40,7 +41,7 @@ $SIG{__WARN__} = sub { warn "Warn: ", @_ };
 $SIG{__DIE__}  = sub { die "Error: ", @_ };
 
 # Global variables:
-our $VERSION   = '0.17';
+our $VERSION   = '0.18';
 our $share_dir = dist_dir('Convert-Pheno');
 
 ############################################
@@ -92,6 +93,15 @@ has username => (
     isa => Str
 );
 
+has id => (
+    default => time . substr( "00000$$", -5 ),
+    is      => 'ro',
+    coerce  => sub {
+        $_[0] // time . substr( "00000$$", -5 );
+    },
+    isa => Str
+);
+
 has max_lines_sql => (
     default => 500,                    # Limit to speed up runtime
     is      => 'ro',
@@ -150,11 +160,11 @@ has [qw /data method/] => ( is => 'rw' );
 
 #############
 #############
-#  PXF2BFF  #
+#  BFF2PXF  #
 #############
 #############
 
-sub pxf2bff {
+sub bff2pxf {
 
     # <array_dispatcher> will deal with JSON arrays
     return array_dispatcher(shift);
@@ -162,11 +172,23 @@ sub pxf2bff {
 
 #############
 #############
-#  BFF2PXF  #
+#  BFF2CSV  #
 #############
 #############
 
-sub bff2pxf {
+sub bff2csv {
+
+    # <array_dispatcher> will deal with JSON arrays
+    return array_dispatcher(shift);
+}
+
+#############
+#############
+# BFF2JSONF #
+#############
+#############
+
+sub bff2jsonf {
 
     # <array_dispatcher> will deal with JSON arrays
     return array_dispatcher(shift);
@@ -198,6 +220,8 @@ sub redcap2bff {
     $self->{data}              = $data;                 # Dynamically adding attributes (setter)
     $self->{data_redcap_dict}  = $data_redcap_dict;     # Dynamically adding attributes (setter)
     $self->{data_mapping_file} = $data_mapping_file;    # Dynamically adding attributes (setter)
+    $self->{metaData}          = get_metaData($self);
+    $self->{convertPheno}      = get_info($self);
 
     # array_dispatcher will deal with JSON arrays
     return array_dispatcher($self);
@@ -407,6 +431,10 @@ sub omop2bff {
     # Giving some memory back to the system
     $data = undef;
 
+    # Adding miscellanea metadata
+    $self->{metaData}     = get_metaData($self);                         # setter
+    $self->{convertPheno} = get_info($self);                             # setter
+
     # --stream
     if ( $self->{stream} ) {
         omop_stream_dispatcher(
@@ -522,6 +550,42 @@ sub cdisc2pxf {
     return array_dispatcher($self);
 }
 
+#############
+#############
+#  PXF2BFF  #
+#############
+#############
+
+sub pxf2bff {
+
+    # <array_dispatcher> will deal with JSON arrays
+    return array_dispatcher(shift);
+}
+
+#############
+#############
+#  PXF2CSV  #
+#############
+#############
+
+sub pxf2csv {
+
+    # <array_dispatcher> will deal with JSON arrays
+    return array_dispatcher(shift);
+}
+
+#############
+#############
+# PXFJSONF #
+#############
+#############
+
+sub pxf2jsonf {
+
+    # <array_dispatcher> will deal with JSON arrays
+    return array_dispatcher(shift);
+}
+
 ######################
 ######################
 #  MISCELLANEA SUBS  #
@@ -540,11 +604,15 @@ sub array_dispatcher {
 
     # Define the methods to call (naming 'func' to avoid confussion with $self->{method})
     my %func = (
-        pxf2bff    => \&do_pxf2bff,
         redcap2bff => \&do_redcap2bff,
         cdisc2bff  => \&do_cdisc2bff,
         omop2bff   => \&do_omop2bff,
-        bff2pxf    => \&do_bff2pxf
+        bff2pxf    => \&do_bff2pxf,
+        bff2csv    => \&do_bff2csv,
+        bff2jsonf  => \&do_bff2csv,      # Not a typo, is the same as above
+        pxf2bff    => \&do_pxf2bff,
+        pxf2csv    => \&do_pxf2csv,
+        pxf2jsonf  => \&do_pxf2csv      # Not a typo, is the same as above
     );
 
     # Open connection to SQLlite databases ONCE
@@ -783,7 +851,7 @@ L<https://github.com/CNAG-Biomedical-Informatics/convert-pheno#readme>
 
 The author requests that any published work that utilizes C<Convert-Pheno> includes a cite to the the following reference:
 
-Rueda, M. et al. "Convert-Pheno: A software toolkit for the interconversion of standard data models for phenotypic data", (2023), I<Journal of Biomedical Informatics>.
+Rueda, M et al., (2024). Convert-Pheno: A software toolkit for the interconversion of standard data models for phenotypic data. Journal of Biomedical Informatics. L<DOI|https://doi.org/10.1016/j.jbi.2023.104558>
 
 =head1 AUTHOR
 
